==> unit_testing-1.0.2.tar.gz: unit_testing-1.0.2/README.md <==
# 5G00EV17-3001 Unit testing

An example project for showcasing unit testing.

|   Category   |  Badges  |
|:------------:|---|
| **PyPI**     | ![Python versions](https://img.shields.io/pypi/pyversions/iplib3?logo=python) ![PyPI - Implementation](https://img.shields.io/pypi/implementation/iplib3) |
| **Tests**    | [![codecov](https://codecov.io/gh/Diapolo10/5G00EV17-3001_unit-testing/branch/main/graph/badge.svg?token=FpaCuVjOAB)](https://codecov.io/gh/Diapolo10/5G00EV17-3001_unit-testing) ![Unit tests](https://github.com/diapolo10/5G00EV17-3001_unit-testing/workflows/Unit%20tests/badge.svg) ![Unit tests](https://github.com/diapolo10/5G00EV17-3001_unit-testing/workflows/Pylint/badge.svg) ![Unit tests](https://github.com/diapolo10/5G00EV17-3001_unit-testing/workflows/Flake8/badge.svg) |
| **Activity** | ![GitHub contributors](https://img.shields.io/github/contributors/diapolo10/5G00EV17-3001_unit-testing) ![Last commit](https://img.shields.io/github/last-commit/diapolo10/5G00EV17-3001_unit-testing?logo=github)
| **QA**       | [![CodeFactor](https://www.codefactor.io/repository/github/diapolo10/5G00EV17-3001_unit-testing/badge?logo=codefactor)](https://www.codefactor.io/repository/github/diapolo10/5G00EV17-3001_unit-testing) [![Rating](https://img.shields.io/librariesio/sourcerank/pypi/iplib3)](https://libraries.io/github/Diapolo10/iplib3/sourcerank) |
| **Other**    | [![License](https://img.shields.io/github/license/diapolo10/5G00EV17-3001_unit-testing)](https://opensource.org/licenses/MIT) ![Repository size](https://img.shields.io/github/repo-size/diapolo10/5G00EV17-3001_unit-testing?logo=github) ![Code size](https://img.shields.io/github/languages/code-size/diapolo10/5G00EV17-3001_unit-testing?logo=github) ![Lines of code](https://img.shields.io/tokei/lines/github/diapolo10/5G00EV17-3001_unit-testing?logo=github) |

-------------------------------------------------------------------------------

## Description

This project showcases how unit testing works by implementing a very simple
Python library, and adding unit tests to it. The project uses Pytest.

## Getting Started

### Dependencies

The main project has no library dependencies, but the actual unit testing
part relies on several packages listed in
[`pyproject.toml`][pyproject.toml]. But in general, you'll need:

- Python 3.7 or newer
- Poetry

The project is automatically tested on the latest versions of Windows,
Mac OS, and Ubuntu, and it has also been tested on both CPython
and PyPy. Using other implementations or operating systems
may work, but is not guaranteed.

### Installation

Please see the documentation [here][installation].

### Running unit tests

Please see the documentation [here][running unit tests].

## Version history

The project's changelog can be found [here][changelog].

## License

This project is licensed under the MIT license - see the [`LICENSE`][license]-file for details.

## Acknowledgements

Inspiration, code snippets, debugging help, etc.

- My fellow team members

[pyproject.toml]: ./pyproject.toml
[installation]: ./docs/installation.md
[running unit tests]: ./docs/running_unit_tests.md
[changelog]: ./CHANGELOG.md
[license]: ./LICENSE

==> unit_testing-1.0.3.tar.gz: unit_testing-1.0.3/README.md <==
# 5G00EV17-3001 Unit testing

An example project for showcasing unit testing.

|   Category   |  Badges  |
|:------------:|---|
| **PyPI**     | ![Python versions](https://img.shields.io/pypi/pyversions/5G00EV17-3001_unit-testing?logo=python) ![PyPI - Implementation](https://img.shields.io/pypi/implementation/5G00EV17-3001_unit-testing) |
| **Tests**    | [![codecov](https://codecov.io/gh/Diapolo10/5G00EV17-3001_unit-testing/branch/main/graph/badge.svg?token=FpaCuVjOAB)](https://codecov.io/gh/Diapolo10/5G00EV17-3001_unit-testing) ![Unit tests](https://github.com/diapolo10/5G00EV17-3001_unit-testing/workflows/Unit%20tests/badge.svg) ![Unit tests](https://github.com/diapolo10/5G00EV17-3001_unit-testing/workflows/Pylint/badge.svg) ![Unit tests](https://github.com/diapolo10/5G00EV17-3001_unit-testing/workflows/Flake8/badge.svg) |
| **Activity** | ![GitHub contributors](https://img.shields.io/github/contributors/diapolo10/5G00EV17-3001_unit-testing) ![Last commit](https://img.shields.io/github/last-commit/diapolo10/5G00EV17-3001_unit-testing?logo=github)
| **QA**       | [![CodeFactor](https://www.codefactor.io/repository/github/diapolo10/5G00EV17-3001_unit-testing/badge?logo=codefactor)](https://www.codefactor.io/repository/github/diapolo10/5G00EV17-3001_unit-testing) [![Rating](https://img.shields.io/librariesio/sourcerank/pypi/5G00EV17-3001_unit-testing)](https://libraries.io/github/Diapolo10/5G00EV17-3001_unit-testing/sourcerank) |
| **Other**    | [![License](https://img.shields.io/github/license/diapolo10/5G00EV17-3001_unit-testing)](https://opensource.org/licenses/MIT) ![Repository size](https://img.shields.io/github/repo-size/diapolo10/5G00EV17-3001_unit-testing?logo=github) ![Code size](https://img.shields.io/github/languages/code-size/diapolo10/5G00EV17-3001_unit-testing?logo=github) ![Lines of code](https://img.shields.io/tokei/lines/github/diapolo10/5G00EV17-3001_unit-testing?logo=github) |

-------------------------------------------------------------------------------

## Description

This project showcases how unit testing works by implementing a very simple
Python library, and adding unit tests to it. The project uses Pytest.

## Getting Started

### Dependencies

The main project has no library dependencies, but the actual unit testing
part relies on several packages listed in
[`pyproject.toml`][pyproject.toml]. But in general, you'll need:

- Python 3.11 or newer
- Poetry

The project is automatically tested on the latest versions of Windows,
Mac OS, and Ubuntu, and it has also been tested on both CPython
and PyPy. Using other implementations or operating systems
may work, but is not guaranteed.

### Installation

Please see the documentation [here][installation].

### Running unit tests

Please see the documentation [here][running unit tests].

## Version history

The project's changelog can be found [here][changelog].

## License

This project is licensed under the MIT license - see the [`LICENSE`][license]-file for details.

## Acknowledgements

Inspiration, code snippets, debugging help, etc.

- My fellow team members

[pyproject.toml]: ./pyproject.toml
[installation]: ./docs/installation.md
[running unit tests]: ./docs/running_unit_tests.md
[changelog]: ./CHANGELOG.md
[license]: ./LICENSE
